==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/TLSSecurityProfileFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class TLSSecurityProfileFluentImpl<A extends io.fabric8.openshift.api.model.TLSSecurityProfileFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent<A>{
  public TLSSecurityProfileFluentImpl() {
  }
  public TLSSecurityProfileFluentImpl(io.fabric8.openshift.api.model.TLSSecurityProfile instance) {
    this.withCustom(instance.getCustom()); 
    this.withIntermediate(instance.getIntermediate()); 
    this.withModern(instance.getModern()); 
    this.withOld(instance.getOld()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.CustomTLSProfileBuilder custom;
  private io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder intermediate;
  private io.fabric8.openshift.api.model.ModernTLSProfileBuilder modern;
  private io.fabric8.openshift.api.model.OldTLSProfileBuilder old;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCustom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.CustomTLSProfile getCustom() {
    return this.custom!=null?this.custom.build():null;
  }
  public io.fabric8.openshift.api.model.CustomTLSProfile buildCustom() {
    return this.custom!=null?this.custom.build():null;
  }
  public A withCustom(io.fabric8.openshift.api.model.CustomTLSProfile custom) {
    _visitables.get("custom").remove(this.custom);
    if (custom!=null){ this.custom= new io.fabric8.openshift.api.model.CustomTLSProfileBuilder(custom); _visitables.get("custom").add(this.custom);} return (A) this;
  }
  public java.lang.Boolean hasCustom() {
    return this.custom != null;
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> withNewCustom() {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.CustomNestedImpl();
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> withNewCustomLike(io.fabric8.openshift.api.model.CustomTLSProfile item) {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.CustomNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> editCustom() {
    return withNewCustomLike(getCustom());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> editOrNewCustom() {
    return withNewCustomLike(getCustom() != null ? getCustom(): new io.fabric8.openshift.api.model.CustomTLSProfileBuilder().build());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> editOrNewCustomLike(io.fabric8.openshift.api.model.CustomTLSProfile item) {
    return withNewCustomLike(getCustom() != null ? getCustom(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIntermediate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.IntermediateTLSProfile getIntermediate() {
    return this.intermediate!=null?this.intermediate.build():null;
  }
  public io.fabric8.openshift.api.model.IntermediateTLSProfile buildIntermediate() {
    return this.intermediate!=null?this.intermediate.build():null;
  }
  public A withIntermediate(io.fabric8.openshift.api.model.IntermediateTLSProfile intermediate) {
    _visitables.get("intermediate").remove(this.intermediate);
    if (intermediate!=null){ this.intermediate= new io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder(intermediate); _visitables.get("intermediate").add(this.intermediate);} return (A) this;
  }
  public java.lang.Boolean hasIntermediate() {
    return this.intermediate != null;
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediate() {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.IntermediateNestedImpl();
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediateLike(io.fabric8.openshift.api.model.IntermediateTLSProfile item) {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.IntermediateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> editIntermediate() {
    return withNewIntermediateLike(getIntermediate());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediate() {
    return withNewIntermediateLike(getIntermediate() != null ? getIntermediate(): new io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder().build());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediateLike(io.fabric8.openshift.api.model.IntermediateTLSProfile item) {
    return withNewIntermediateLike(getIntermediate() != null ? getIntermediate(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildModern instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ModernTLSProfile getModern() {
    return this.modern!=null?this.modern.build():null;
  }
  public io.fabric8.openshift.api.model.ModernTLSProfile buildModern() {
    return this.modern!=null?this.modern.build():null;
  }
  public A withModern(io.fabric8.openshift.api.model.ModernTLSProfile modern) {
    _visitables.get("modern").remove(this.modern);
    if (modern!=null){ this.modern= new io.fabric8.openshift.api.model.ModernTLSProfileBuilder(modern); _visitables.get("modern").add(this.modern);} return (A) this;
  }
  public java.lang.Boolean hasModern() {
    return this.modern != null;
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> withNewModern() {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.ModernNestedImpl();
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> withNewModernLike(io.fabric8.openshift.api.model.ModernTLSProfile item) {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.ModernNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> editModern() {
    return withNewModernLike(getModern());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> editOrNewModern() {
    return withNewModernLike(getModern() != null ? getModern(): new io.fabric8.openshift.api.model.ModernTLSProfileBuilder().build());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> editOrNewModernLike(io.fabric8.openshift.api.model.ModernTLSProfile item) {
    return withNewModernLike(getModern() != null ? getModern(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildOld instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.OldTLSProfile getOld() {
    return this.old!=null?this.old.build():null;
  }
  public io.fabric8.openshift.api.model.OldTLSProfile buildOld() {
    return this.old!=null?this.old.build():null;
  }
  public A withOld(io.fabric8.openshift.api.model.OldTLSProfile old) {
    _visitables.get("old").remove(this.old);
    if (old!=null){ this.old= new io.fabric8.openshift.api.model.OldTLSProfileBuilder(old); _visitables.get("old").add(this.old);} return (A) this;
  }
  public java.lang.Boolean hasOld() {
    return this.old != null;
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> withNewOld() {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.OldNestedImpl();
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> withNewOldLike(io.fabric8.openshift.api.model.OldTLSProfile item) {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.OldNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> editOld() {
    return withNewOldLike(getOld());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> editOrNewOld() {
    return withNewOldLike(getOld() != null ? getOld(): new io.fabric8.openshift.api.model.OldTLSProfileBuilder().build());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> editOrNewOldLike(io.fabric8.openshift.api.model.OldTLSProfile item) {
    return withNewOldLike(getOld() != null ? getOld(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TLSSecurityProfileFluentImpl that = (TLSSecurityProfileFluentImpl) o;
    if (custom != null ? !custom.equals(that.custom) :that.custom != null) return false;
    if (intermediate != null ? !intermediate.equals(that.intermediate) :that.intermediate != null) return false;
    if (modern != null ? !modern.equals(that.modern) :that.modern != null) return false;
    if (old != null ? !old.equals(that.old) :that.old != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(custom,  intermediate,  modern,  old,  type,  additionalProperties,  super.hashCode());
  }
  public class CustomNestedImpl<N> extends io.fabric8.openshift.api.model.CustomTLSProfileFluentImpl<io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<N>> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CustomNestedImpl(io.fabric8.openshift.api.model.CustomTLSProfile item) {
      this.builder = new io.fabric8.openshift.api.model.CustomTLSProfileBuilder(this, item);
    }
    CustomNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.CustomTLSProfileBuilder(this);
    }
    io.fabric8.openshift.api.model.CustomTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withCustom(builder.build());
    }
    public N endCustom() {
      return and();
    }
    
  }
  public class IntermediateNestedImpl<N> extends io.fabric8.openshift.api.model.IntermediateTLSProfileFluentImpl<io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<N>> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IntermediateNestedImpl(io.fabric8.openshift.api.model.IntermediateTLSProfile item) {
      this.builder = new io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder(this, item);
    }
    IntermediateNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder(this);
    }
    io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withIntermediate(builder.build());
    }
    public N endIntermediate() {
      return and();
    }
    
  }
  public class ModernNestedImpl<N> extends io.fabric8.openshift.api.model.ModernTLSProfileFluentImpl<io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<N>> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ModernNestedImpl(io.fabric8.openshift.api.model.ModernTLSProfile item) {
      this.builder = new io.fabric8.openshift.api.model.ModernTLSProfileBuilder(this, item);
    }
    ModernNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ModernTLSProfileBuilder(this);
    }
    io.fabric8.openshift.api.model.ModernTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withModern(builder.build());
    }
    public N endModern() {
      return and();
    }
    
  }
  public class OldNestedImpl<N> extends io.fabric8.openshift.api.model.OldTLSProfileFluentImpl<io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<N>> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    OldNestedImpl(io.fabric8.openshift.api.model.OldTLSProfile item) {
      this.builder = new io.fabric8.openshift.api.model.OldTLSProfileBuilder(this, item);
    }
    OldNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.OldTLSProfileBuilder(this);
    }
    io.fabric8.openshift.api.model.OldTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withOld(builder.build());
    }
    public N endOld() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/TLSSecurityProfileFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class TLSSecurityProfileFluentImpl<A extends io.fabric8.openshift.api.model.TLSSecurityProfileFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent<A>{
  public TLSSecurityProfileFluentImpl() {
  }
  public TLSSecurityProfileFluentImpl(io.fabric8.openshift.api.model.TLSSecurityProfile instance) {
    this.withCustom(instance.getCustom()); 
    this.withIntermediate(instance.getIntermediate()); 
    this.withModern(instance.getModern()); 
    this.withOld(instance.getOld()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.CustomTLSProfileBuilder custom;
  private io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder intermediate;
  private io.fabric8.openshift.api.model.ModernTLSProfileBuilder modern;
  private io.fabric8.openshift.api.model.OldTLSProfileBuilder old;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCustom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.CustomTLSProfile getCustom() {
    return this.custom!=null?this.custom.build():null;
  }
  public io.fabric8.openshift.api.model.CustomTLSProfile buildCustom() {
    return this.custom!=null?this.custom.build():null;
  }
  public A withCustom(io.fabric8.openshift.api.model.CustomTLSProfile custom) {
    _visitables.get("custom").remove(this.custom);
    if (custom!=null){ this.custom= new io.fabric8.openshift.api.model.CustomTLSProfileBuilder(custom); _visitables.get("custom").add(this.custom);} return (A) this;
  }
  public java.lang.Boolean hasCustom() {
    return this.custom != null;
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> withNewCustom() {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.CustomNestedImpl();
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> withNewCustomLike(io.fabric8.openshift.api.model.CustomTLSProfile item) {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.CustomNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> editCustom() {
    return withNewCustomLike(getCustom());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> editOrNewCustom() {
    return withNewCustomLike(getCustom() != null ? getCustom(): new io.fabric8.openshift.api.model.CustomTLSProfileBuilder().build());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<A> editOrNewCustomLike(io.fabric8.openshift.api.model.CustomTLSProfile item) {
    return withNewCustomLike(getCustom() != null ? getCustom(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIntermediate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.IntermediateTLSProfile getIntermediate() {
    return this.intermediate!=null?this.intermediate.build():null;
  }
  public io.fabric8.openshift.api.model.IntermediateTLSProfile buildIntermediate() {
    return this.intermediate!=null?this.intermediate.build():null;
  }
  public A withIntermediate(io.fabric8.openshift.api.model.IntermediateTLSProfile intermediate) {
    _visitables.get("intermediate").remove(this.intermediate);
    if (intermediate!=null){ this.intermediate= new io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder(intermediate); _visitables.get("intermediate").add(this.intermediate);} return (A) this;
  }
  public java.lang.Boolean hasIntermediate() {
    return this.intermediate != null;
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediate() {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.IntermediateNestedImpl();
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediateLike(io.fabric8.openshift.api.model.IntermediateTLSProfile item) {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.IntermediateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> editIntermediate() {
    return withNewIntermediateLike(getIntermediate());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediate() {
    return withNewIntermediateLike(getIntermediate() != null ? getIntermediate(): new io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder().build());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediateLike(io.fabric8.openshift.api.model.IntermediateTLSProfile item) {
    return withNewIntermediateLike(getIntermediate() != null ? getIntermediate(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildModern instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ModernTLSProfile getModern() {
    return this.modern!=null?this.modern.build():null;
  }
  public io.fabric8.openshift.api.model.ModernTLSProfile buildModern() {
    return this.modern!=null?this.modern.build():null;
  }
  public A withModern(io.fabric8.openshift.api.model.ModernTLSProfile modern) {
    _visitables.get("modern").remove(this.modern);
    if (modern!=null){ this.modern= new io.fabric8.openshift.api.model.ModernTLSProfileBuilder(modern); _visitables.get("modern").add(this.modern);} return (A) this;
  }
  public java.lang.Boolean hasModern() {
    return this.modern != null;
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> withNewModern() {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.ModernNestedImpl();
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> withNewModernLike(io.fabric8.openshift.api.model.ModernTLSProfile item) {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.ModernNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> editModern() {
    return withNewModernLike(getModern());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> editOrNewModern() {
    return withNewModernLike(getModern() != null ? getModern(): new io.fabric8.openshift.api.model.ModernTLSProfileBuilder().build());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<A> editOrNewModernLike(io.fabric8.openshift.api.model.ModernTLSProfile item) {
    return withNewModernLike(getModern() != null ? getModern(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildOld instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.OldTLSProfile getOld() {
    return this.old!=null?this.old.build():null;
  }
  public io.fabric8.openshift.api.model.OldTLSProfile buildOld() {
    return this.old!=null?this.old.build():null;
  }
  public A withOld(io.fabric8.openshift.api.model.OldTLSProfile old) {
    _visitables.get("old").remove(this.old);
    if (old!=null){ this.old= new io.fabric8.openshift.api.model.OldTLSProfileBuilder(old); _visitables.get("old").add(this.old);} return (A) this;
  }
  public java.lang.Boolean hasOld() {
    return this.old != null;
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> withNewOld() {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.OldNestedImpl();
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> withNewOldLike(io.fabric8.openshift.api.model.OldTLSProfile item) {
    return new io.fabric8.openshift.api.model.TLSSecurityProfileFluentImpl.OldNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> editOld() {
    return withNewOldLike(getOld());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> editOrNewOld() {
    return withNewOldLike(getOld() != null ? getOld(): new io.fabric8.openshift.api.model.OldTLSProfileBuilder().build());
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<A> editOrNewOldLike(io.fabric8.openshift.api.model.OldTLSProfile item) {
    return withNewOldLike(getOld() != null ? getOld(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TLSSecurityProfileFluentImpl that = (TLSSecurityProfileFluentImpl) o;
    if (custom != null ? !custom.equals(that.custom) :that.custom != null) return false;
    if (intermediate != null ? !intermediate.equals(that.intermediate) :that.intermediate != null) return false;
    if (modern != null ? !modern.equals(that.modern) :that.modern != null) return false;
    if (old != null ? !old.equals(that.old) :that.old != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(custom,  intermediate,  modern,  old,  type,  additionalProperties,  super.hashCode());
  }
  public class CustomNestedImpl<N> extends io.fabric8.openshift.api.model.CustomTLSProfileFluentImpl<io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<N>> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent.CustomNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CustomNestedImpl(io.fabric8.openshift.api.model.CustomTLSProfile item) {
      this.builder = new io.fabric8.openshift.api.model.CustomTLSProfileBuilder(this, item);
    }
    CustomNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.CustomTLSProfileBuilder(this);
    }
    io.fabric8.openshift.api.model.CustomTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withCustom(builder.build());
    }
    public N endCustom() {
      return and();
    }
    
  }
  public class IntermediateNestedImpl<N> extends io.fabric8.openshift.api.model.IntermediateTLSProfileFluentImpl<io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<N>> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent.IntermediateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IntermediateNestedImpl(io.fabric8.openshift.api.model.IntermediateTLSProfile item) {
      this.builder = new io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder(this, item);
    }
    IntermediateNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder(this);
    }
    io.fabric8.openshift.api.model.IntermediateTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withIntermediate(builder.build());
    }
    public N endIntermediate() {
      return and();
    }
    
  }
  public class ModernNestedImpl<N> extends io.fabric8.openshift.api.model.ModernTLSProfileFluentImpl<io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<N>> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent.ModernNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ModernNestedImpl(io.fabric8.openshift.api.model.ModernTLSProfile item) {
      this.builder = new io.fabric8.openshift.api.model.ModernTLSProfileBuilder(this, item);
    }
    ModernNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ModernTLSProfileBuilder(this);
    }
    io.fabric8.openshift.api.model.ModernTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withModern(builder.build());
    }
    public N endModern() {
      return and();
    }
    
  }
  public class OldNestedImpl<N> extends io.fabric8.openshift.api.model.OldTLSProfileFluentImpl<io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<N>> implements io.fabric8.openshift.api.model.TLSSecurityProfileFluent.OldNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    OldNestedImpl(io.fabric8.openshift.api.model.OldTLSProfile item) {
      this.builder = new io.fabric8.openshift.api.model.OldTLSProfileBuilder(this, item);
    }
    OldNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.OldTLSProfileBuilder(this);
    }
    io.fabric8.openshift.api.model.OldTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withOld(builder.build());
    }
    public N endOld() {
      return and();
    }
    
  }
  
}
